## Description
Describe one (and only one) issue or enhancement you want to see in Intro.js (before writing any code).

## Expected Behavior
What did you expect to happen?

## Actual Behavior
What actually happened?

## Errors and Screenshots (optional)
Give us any additional information if you have.

## Example (recommended)
How can someone else see/test this issue?  List the steps or write some code; or create a jsfiddle or codepen.

## Environment (optional)
List browser information, Intro.js version, Operating System, JavaScript libraries (jQuery, Angular, React), etc.
